@@ -31,6 +31,23 @@ class JobsModel(BaseModel):
     pass
 
 
-
 class JobsOrganizationModel(JobsModel):
-    organization: uuid.UUID = Field(index=True)
\ No newline at end of file
+    organization: uuid.UUID = Field(index=True)
+
+
+## Billing
+class BillingModel(BaseModel):
+    pass
+
+
+class BillingOrganizationModel(BillingModel):
+    organization: uuid.UUID = Field(index=True)
+
+
+## IAM
+class IAMModel(BaseModel):
+    pass
+
+
+class IAMOrganizationModel(BaseModel):
+    organization: uuid.UUID = Field(index=True)
